==> jc-1.4.0.tar.gz: javax/swing/Box__24AccessibleBox.h <==
// public class javax.swing.Box$AccessibleBox

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ff1a51f62c9d0698 javax_swing_Box__24AccessibleBox

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_Box__24AccessibleBox_H_
#define _JC_javax_swing_Box__24AccessibleBox_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_Box$object;

// Typedefs
typedef struct _jc_javax_swing_Box__24AccessibleBox$sub_refs	_jc_javax_swing_Box__24AccessibleBox$sub_refs;
typedef struct _jc_javax_swing_Box__24AccessibleBox$sub_nonrefs	_jc_javax_swing_Box__24AccessibleBox$sub_nonrefs;
typedef struct _jc_javax_swing_Box__24AccessibleBox$refs	_jc_javax_swing_Box__24AccessibleBox$refs;
typedef struct _jc_javax_swing_Box__24AccessibleBox$nonrefs	_jc_javax_swing_Box__24AccessibleBox$nonrefs;
typedef struct _jc_javax_swing_Box__24AccessibleBox$object	_jc_javax_swing_Box__24AccessibleBox$object;

typedef struct _jc_javax_swing_Box__24AccessibleBox$fields_struct	_jc_javax_swing_Box__24AccessibleBox$fields_struct;
typedef const struct _jc_javax_swing_Box__24AccessibleBox$vmethods	_jc_javax_swing_Box__24AccessibleBox$vmethods;
typedef const struct _jc_javax_swing_Box__24AccessibleBox$vtable	_jc_javax_swing_Box__24AccessibleBox$vtable;
typedef const struct _jc_javax_swing_Box__24AccessibleBox$vtype	_jc_javax_swing_Box__24AccessibleBox$vtype;

// Class fields structure
struct _jc_javax_swing_Box__24AccessibleBox$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_Box__24AccessibleBox$fields_struct _jc_javax_swing_Box__24AccessibleBox$class_fields;

// Constructors
extern void _jc_javax_swing_Box__24AccessibleBox$method$_init$5d8fb50623707553(_jc_env *, struct _jc_javax_swing_Box__24AccessibleBox$object *, struct _jc_javax_swing_Box$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_Box__24AccessibleBox$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_Box__24AccessibleBox$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_Box__24AccessibleBox$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_javax_swing_Box__24AccessibleBox$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_Box__24AccessibleBox$object *);
};

// Vtable
struct _jc_javax_swing_Box__24AccessibleBox$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_Box__24AccessibleBox$vmethods	javax_swing_Box__24AccessibleBox;
};

// Vtype
struct _jc_javax_swing_Box__24AccessibleBox$vtype {
	_jc_type			type;
	_jc_javax_swing_Box__24AccessibleBox$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_Box__24AccessibleBox$sub_refs {
	struct _jc_javax_swing_Box$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_Box__24AccessibleBox$refs {
    _jc_javax_swing_Box__24AccessibleBox$sub_refs	javax_swing_Box__24AccessibleBox;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_Box__24AccessibleBox$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_Box__24AccessibleBox$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_Box__24AccessibleBox$sub_nonrefs	javax_swing_Box__24AccessibleBox;
};

// Object instance structure
struct _jc_javax_swing_Box__24AccessibleBox$object {
	_jc_javax_swing_Box__24AccessibleBox$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_Box__24AccessibleBox$vtype	*vtype;
	_jc_javax_swing_Box__24AccessibleBox$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_Box__24AccessibleBox$vtype _jc_javax_swing_Box__24AccessibleBox$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_Box__24AccessibleBox, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_Box__24AccessibleBox$class_object;

#endif	/* _JC_javax_swing_Box__24AccessibleBox_H_ */

==> jc-1.4.6.tar.gz: javax/swing/Box__24AccessibleBox.h <==
// public class javax.swing.Box$AccessibleBox

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ff1a51f62c9d0698 javax_swing_Box__24AccessibleBox

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_Box__24AccessibleBox_H_
#define _JC_javax_swing_Box__24AccessibleBox_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_Box$object;

// Typedefs
typedef struct _jc_javax_swing_Box__24AccessibleBox$sub_refs	_jc_javax_swing_Box__24AccessibleBox$sub_refs;
typedef struct _jc_javax_swing_Box__24AccessibleBox$sub_nonrefs	_jc_javax_swing_Box__24AccessibleBox$sub_nonrefs;
typedef struct _jc_javax_swing_Box__24AccessibleBox$refs	_jc_javax_swing_Box__24AccessibleBox$refs;
typedef struct _jc_javax_swing_Box__24AccessibleBox$nonrefs	_jc_javax_swing_Box__24AccessibleBox$nonrefs;
typedef struct _jc_javax_swing_Box__24AccessibleBox$object	_jc_javax_swing_Box__24AccessibleBox$object;

typedef struct _jc_javax_swing_Box__24AccessibleBox$fields_struct	_jc_javax_swing_Box__24AccessibleBox$fields_struct;
typedef const struct _jc_javax_swing_Box__24AccessibleBox$vmethods	_jc_javax_swing_Box__24AccessibleBox$vmethods;
typedef const struct _jc_javax_swing_Box__24AccessibleBox$vtable	_jc_javax_swing_Box__24AccessibleBox$vtable;
typedef const struct _jc_javax_swing_Box__24AccessibleBox$vtype	_jc_javax_swing_Box__24AccessibleBox$vtype;

// Class fields structure
struct _jc_javax_swing_Box__24AccessibleBox$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_Box__24AccessibleBox$fields_struct _jc_javax_swing_Box__24AccessibleBox$class_fields;

// Constructors
extern void _jc_javax_swing_Box__24AccessibleBox$method$_init$5d8fb50623707553(_jc_env *, struct _jc_javax_swing_Box__24AccessibleBox$object *, struct _jc_javax_swing_Box$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_Box__24AccessibleBox$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_Box__24AccessibleBox$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_Box__24AccessibleBox$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_javax_swing_Box__24AccessibleBox$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_Box__24AccessibleBox$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_Box__24AccessibleBox$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_Box__24AccessibleBox$vmethods	javax_swing_Box__24AccessibleBox;
};

// Vtype
struct _jc_javax_swing_Box__24AccessibleBox$vtype {
	_jc_type			type;
	_jc_javax_swing_Box__24AccessibleBox$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_Box__24AccessibleBox$sub_refs {
	struct _jc_javax_swing_Box$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_Box__24AccessibleBox$refs {
    _jc_javax_swing_Box__24AccessibleBox$sub_refs	javax_swing_Box__24AccessibleBox;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_Box__24AccessibleBox$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_Box__24AccessibleBox$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_Box__24AccessibleBox$sub_nonrefs	javax_swing_Box__24AccessibleBox;
};

// Object instance structure
struct _jc_javax_swing_Box__24AccessibleBox$object {
	_jc_javax_swing_Box__24AccessibleBox$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_Box__24AccessibleBox$vtype	*vtype;
	_jc_javax_swing_Box__24AccessibleBox$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_Box__24AccessibleBox$vtype _jc_javax_swing_Box__24AccessibleBox$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_Box__24AccessibleBox, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_Box__24AccessibleBox$class_object;

#endif	/* _JC_javax_swing_Box__24AccessibleBox_H_ */
